AccessorChoiceOption<T extends Enum> class
final
- Inheritance
-
- Object
- Input<
T?> - AccessorPrimitiveOption<
T?> - AccessorChoiceOption
- Implemented types
- Mixed-in types
Constructors
-
AccessorChoiceOption(String name, {required List<
T> choices, String? description})
Properties
-
choices
→ List<
T> -
final
- description → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
required<
T extends Enum> (String name, {required List< T> choices, String? description}) → RequiredAccessorOption<T> -
withDefault<
T extends Enum> (String name, {required List< T> choices, required T defaultValue, String? description}) → DefaultedAccessorOption<T>