AccessorDoubleOption class final

Inheritance
Implemented types

Constructors

AccessorDoubleOption(String name, {String? description})
const

Properties

description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
regex RegExp
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

required(String name, {String? description}) RequiredAccessorOption<double>
withDefault(String name, {required double defaultValue, String? description}) DefaultedAccessorOption<double>