AccessorStringOption class final

Inheritance
Implemented types
Mixed-in types

Constructors

AccessorStringOption(String name, {String? description, RegExp? regex})

Properties

description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
regex RegExp
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

required(String name, {RegExp? regex, String? description}) RequiredAccessorOption<String>
withDefault(String name, {required String defaultValue, RegExp? regex, String? description}) DefaultedAccessorOption<String>