Command class abstract
Constructors
-
Command({String? longDescription, List<
String> ? aliases, List<MandatoryPositional> ? mandatoryPositionals, List<DiscretionaryPositional> ? discretionaryPositionals, Variadic? variadic, List<Flag> ? flags, List<Option> ? options, List<PairedOptionsDefinition> ? pairedOptions, List<SelectedOptions< ? selectedOptions, List<Object> >AccessorListOption> ? accessors, Map<String, List< ? conflicts})String> >
Properties
-
accessors
→ List<
AccessorListOption> ? -
final
-
aliases
→ List<
String> ? -
final
-
conflicts
→ Map<
String, List< ?String> > -
final
-
discretionaryPositionals
→ List<
DiscretionaryPositional> ? -
final
-
flags
→ List<
Flag> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- longDescription → String?
-
final
-
mandatoryPositionals
→ List<
MandatoryPositional> ? -
final
- name → String
-
no setter
-
options
→ List<
Option> ? -
final
-
pairedOptions
→ List<
PairedOptionsDefinition> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedOptions
→ List<
SelectedOptions< ?Object> > -
final
- shortDescription → String
-
no setter
- variadic → Variadic?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
ParsedInputs inputs, List< String> args) → FutureOr<String?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited