CompletionCommand class

Inheritance

Constructors

CompletionCommand({void createFile(String)?, String? longDescription, List<String>? aliases, List<MandatoryPositional>? mandatoryPositionals, List<DiscretionaryPositional>? discretionaryPositionals, List<Option>? options})
CompletionCommand.preset({required void createFile(String)?, String? longDescription})

Properties

accessors List<AccessorListOption>?
finalinherited
aliases List<String>?
finalinherited
conflicts Map<String, List<String>>?
finalinherited
createFile → void Function(String path)
final
discretionaryPositionals List<DiscretionaryPositional>?
finalinherited
flags List<Flag>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
longDescription String?
finalinherited
mandatoryPositionals List<MandatoryPositional>?
finalinherited
name String
no setteroverride
options List<Option>?
finalinherited
pairedOptions List<PairedOptionsDefinition>?
finalinherited
registryRecord RegistryRecord
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedOptions List<SelectedOptions<Object>>?
finalinherited
shortDescription String
no setteroverride
variadic Variadic?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(ParsedInputs inputs, List<String> args) String?
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited