GroupCommand class abstract
- Inheritance
- Implementers
Constructors
-
GroupCommand(List<
Command> commands, {List<String> ? defaultSubCommandPath, List<String> ? aliases, List<Flag> ? propagatedFlags, List<Option> ? propagatedOptions, String? longDescription, List<MandatoryPositional> ? mandatoryPositionals, List<DiscretionaryPositional> ? discretionaryPositionals, Variadic? variadic, List<Flag> ? flags, List<Option> ? options, List<PairedOptionsDefinition> ? pairedOptions, List<SelectedOptions< ? selectedOptions, List<Object> >AccessorListOption> ? accessors, Map<String, List< ? conflicts})String> >
Properties
-
accessors
→ List<
AccessorListOption> ? -
finalinherited
-
aliases
→ List<
String> ? -
finalinherited
-
commands
→ List<
Command> -
final
-
conflicts
→ Map<
String, List< ?String> > -
finalinherited
-
defaultSubCommandPath
→ List<
String> ? -
final
-
discretionaryPositionals
→ List<
DiscretionaryPositional> ? -
finalinherited
-
flags
→ List<
Flag> ? -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inheritedFlags
→ List<
Flag> ? -
final
-
inheritedOptions
→ List<
Option> ? -
final
- longDescription → String?
-
finalinherited
-
mandatoryPositionals
→ List<
MandatoryPositional> ? -
finalinherited
- name → String
-
no setterinherited
-
options
→ List<
Option> ? -
finalinherited
-
pairedOptions
→ List<
PairedOptionsDefinition> ? -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedOptions
→ List<
SelectedOptions< ?Object> > -
finalinherited
- shortDescription → String
-
no setterinherited
- variadic → Variadic?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
ParsedInputs inputs, List< String> args) → FutureOr<String?> -
override
-
runChildCommand(
List< String> path, ParsedInputs inputs, List<String> args) → FutureOr<String?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited