HookRunner mixin

Superclass constraints

Properties

accessors List<AccessorListOption>?
finalinherited
aliases List<String>?
finalinherited
conflicts Map<String, List<String>>?
finalinherited
discretionaryPositionals List<DiscretionaryPositional>?
finalinherited
flags List<Flag>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
longDescription String?
finalinherited
mandatoryPositionals List<MandatoryPositional>?
finalinherited
name String
no setterinherited
options List<Option>?
finalinherited
pairedOptions List<PairedOptionsDefinition>?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedOptions List<SelectedOptions<Object>>?
finalinherited
shortDescription String
no setterinherited
variadic Variadic?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postRun(ParsedInputs inputs, MambaReadContext context) FutureOr<void>
preRun(ParsedInputs inputs, MambaReadContext context, ProcessedStandardInput? input) FutureOr<void>
run(ParsedInputs inputs, List<String> args) FutureOr<String?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited