IntOption class final

Inheritance
Implemented types
Mixed-in types

Constructors

IntOption(String name, {int? min, int? max, String? short, String? description, bool hidden = false})
const

Properties

description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
finalinherited
isRequired bool
finalinherited
max int?
final
min int?
final
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
short String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

required(String name, {int? min, int? max, String? short, String? description, bool hidden = false}) RequiredOption<int>
withDefault(String name, {required int defaultValue, int? min, int? max, String? short, String? description, bool hidden = false}) DefaultedOption<int>