MambaBuiltInFlags class abstract final

Declarations Mamba uses for its built-in flags.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

dryRun → const BooleanFlag
help → const BooleanFlag
verbose → const CountFlag
version → const BooleanFlag