NormalPositional class final
- Inheritance
-
- Object
- Input<
String> - Positional<
String> - MandatoryPositional<
String> - NormalPositional
Constructors
- NormalPositional(String name, {String? description, RegExp? regExp})
Properties
- description → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
finalinherited
- regex → RegExp
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited