PairDoubleOption class final

Inheritance
Mixed-in types

Constructors

PairDoubleOption(String name, {double? min, double? max, double? step, String? short, String? description})
const

Properties

description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
max double?
final
min double?
final
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
short String?
finalinherited
step double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited