PairedOptions<T extends Object> class final

A group whose members must either all be supplied or all be omitted.

Implemented types

Constructors

PairedOptions(List<PairOption<T>> options, {String? description})
PairedOptions.required(List<PairOption<T>> options, {String? description})

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
options List<PairOption<T>>
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited