ParsedInputs class final

Constructors

ParsedInputs(Map<Object, Object?> values, Iterable<Object> known)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(Object input) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
valueOf<T>(ParsedValue<T> input) → T

Operators

operator ==(Object other) bool
The equality operator.
inherited