RepeatableDoubleOption class final

Inheritance
Mixed-in types

Constructors

RepeatableDoubleOption(String name, {double? min, double? max, double? step, String? short, String? description, bool hidden = false})
const

Properties

description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
finalinherited
isRequired bool
finalinherited
max double?
final
min double?
final
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
short String?
finalinherited
step double?
final
unique bool
no setterinherited

Methods

appendValue(Object value, Object? existing) List<double>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

required(String name, {double? min, double? max, double? step, String? short, String? description, bool hidden = false}) RequiredRepeatableOption<double>
withDefault(String name, {required List<double> defaultValue, double? min, double? max, double? step, String? short, String? description, bool hidden = false}) DefaultedRepeatableOption<double>