RepeatableIntOption class final
Constructors
Properties
- description → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
finalinherited
- isRequired → bool
-
finalinherited
- max → int?
-
final
- min → int?
-
final
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- short → String?
-
finalinherited
- unique → bool
-
no setterinherited
Methods
-
appendValue(
Object value, Object? existing) → List< int> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited