RepeatableOption<T> class sealed

Inheritance
Implemented types
Implementers

Properties

description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
finalinherited
isRequired bool
finalinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
short String?
finalinherited
unique bool
no setteroverride

Methods

appendValue(Object value, Object? existing) List<T>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited