RepeatedStringPositional class final

Inheritance

Constructors

RepeatedStringPositional(String name, {String? description, RegExp? regExp, int times = 1})

Properties

description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
regex RegExp
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
times int
finalinherited

Methods

freezeValues(List<Object> values) List<String>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

optional(String name, {String? description, RegExp? regExp, int times = 1}) OptionalPositional<List<String>>