SelectedOptions<T extends Object> class final

A named collection of pair options that resolves to a map of supplied values.

Implemented types

Constructors

SelectedOptions(List<PairOption<T>> options, {String? description, bool single = false})
SelectedOptions.required(List<PairOption<T>> options, {String? description, bool single = false})

Properties

description String?
final
hashCode int
The hash code for this object.
no setterinherited
options List<PairOption<T>>
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited