StringOption class final

Inheritance
Implemented types
Mixed-in types

Constructors

StringOption(String name, {RegExp? regex, String? short, String? description, bool hidden = false})

Properties

description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
finalinherited
isRequired bool
finalinherited
name String
finalinherited
regex RegExp
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
short String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

required(String name, {RegExp? regex, String? short, String? description, bool hidden = false}) RequiredOption<String>
withDefault(String name, {required String defaultValue, RegExp? regex, String? short, String? description, bool hidden = false}) DefaultedOption<String>