MambaContextKey<T extends Object> class

A typed identity token for a scalar value stored in MambaContext.

Create and share the same key instance between the code that writes a value and the code that reads it. Keys are typed by the primitive returned from MambaContext.get.

Constructors

MambaContextKey()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited