MambaContextValue<T extends Object> class
sealed
A closed scalar value that can be stored in MambaContext.
Applications cannot add context value variants. Use one of MambaContextString, MambaContextBool, MambaContextInt, or MambaContextDouble to store hook state.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
The scalar wrapped by this context value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited