get<T extends Object> method
Returns the unwrapped primitive associated with key, if one has been
set.
Implementation
T? get<T extends Object>(MambaContextKey<T> key) {
return _context.get(key);
}
Returns the unwrapped primitive associated with key, if one has been
set.
T? get<T extends Object>(MambaContextKey<T> key) {
return _context.get(key);
}