fake method

Creates an executor that returns results without process side effects.

Supply standardInput to test a command that reads piped input in its HookRunner.preRun method.

Implementation

MambaExecutor<MambaExecutionResult> fake({
  ProcessedStandardInput? standardInput,
}) => _FakeExecutor(
  _Execution(this, readStandardInput: () async => standardInput),
);