FormattedString extension type

An ANSI-styled fragment that a help formatter can compose safely.

The base type rejects unstyled content so delimiter wrappers cannot be confused with an unformatted command grammar.

on
Implementers

Constructors

FormattedString(String string)

Properties

string String
final