HelpFormatter class abstract

The customization boundary for rendering a CommandRegistry as help text.

Implementers

Constructors

HelpFormatter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(CommandRegistry registry) String
Renders all visible help for registry.
formatIntoEntryDescription(String string) EntryDescriptionString
formatIntoOptionalString(String string) OptionalString
formatIntoOrString(String primaryMember, Iterable<String> alternativeMembers) OrString
formatIntoPairString(String primaryMember, Iterable<String> pairMembers) PairString
formatIntoRequiredString(String string) RequiredString
formatIntoSectionTitle(String string) SectionTitleString
formatIntoSelectionString(String primaryMember, Iterable<String> selectableMembers) SelectionString
formatLongDescription(StringBuffer buffer, String longDescription) → void
Writes a registry long description into buffer.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited