MambaHelpFormatter class final
Renders a CommandRegistry as ANSI-styled command-line help text.
The output contains usage, an optional long description, and non-empty Arguments, Flags, Accessor flags, Options, and Commands sections. Hidden inputs are accepted by Mamba but omitted from this formatter's output.
- Inheritance
-
- Object
- HelpFormatter
- MambaHelpFormatter
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
format(
CommandRegistry registry) → String -
Renders all visible help for
registry.override -
formatIntoEntryDescription(
String string) → EntryDescriptionString -
inherited
-
formatIntoOptionalString(
String string) → OptionalString -
inherited
-
formatIntoOrString(
String primaryMember, Iterable< String> alternativeMembers) → OrString -
inherited
-
formatIntoPairString(
String primaryMember, Iterable< String> pairMembers) → PairString -
inherited
-
formatIntoRequiredString(
String string) → RequiredString -
inherited
-
formatIntoSectionTitle(
String string) → SectionTitleString -
inherited
-
formatIntoSelectionString(
String primaryMember, Iterable< String> selectableMembers) → SelectionString -
inherited
-
formatLongDescription(
StringBuffer buffer, String longDescription) → void -
Writes a registry long description into
buffer.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited