ToZshCompletionConverter class final
Compiles a registry record into a native Zsh completion function.
- Inheritance
-
- Object
- RegistryRecordConverter
- ToZshCompletionConverter
Constructors
- ToZshCompletionConverter(RegistryRecord registry)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- registry → RegistryRecord
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
convert(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited