RegistryAccessor class final

Constructors

RegistryAccessor.group({required String name, required bool? hidden, String? description, required List<RegistryAccessor> options})
RegistryAccessor.value({required String name, required String? valueType, String? description, List<String>? choices, String? defaultValue, String? pattern})

Properties

choices List<String>?
final
defaultValue String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
hidden bool?
final
kind String
final
name String
final
options List<RegistryAccessor>?
final
pattern String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueType String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited