RegistryCommand class final

Constructors

RegistryCommand({required String name, required String description, List<String>? aliases, List<RegistryCommand>? commands, RegistryVariadic? variadic, List<RegistryPositional>? positionals, List<RegistryFlag>? flags, List<RegistryFlag>? persistentFlags, List<RegistryOption>? options, List<RegistryOption>? persistentOptions, List<RegistryOptionGroup>? optionGroups, List<RegistryAccessor>? accessors})

Properties

accessors List<RegistryAccessor>?
final
aliases List<String>?
final
commands List<RegistryCommand>?
final
description String
final
flags List<RegistryFlag>?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
optionGroups List<RegistryOptionGroup>?
final
options List<RegistryOption>?
final
persistentFlags List<RegistryFlag>?
final
persistentOptions List<RegistryOption>?
final
positionals List<RegistryPositional>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variadic RegistryVariadic?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited