AccessorListOption class final
Constructors
-
AccessorListOption(String name, List<
AccessorOption> options, {String? description, })
Properties
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
final
- name → String
-
final
-
options
→ List<
AccessorOption> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited