BooleanFlag class final

Inheritance
Implemented types

Constructors

BooleanFlag(String name, {String? short, String? description, bool hidden = false, bool defaultValue = false, bool negatable = false})
const

Properties

defaultValue bool
final
description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
finalinherited
name String
finalinherited
negatable bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
short String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited