ChoiceOption<T extends Enum> class
final
- Inheritance
-
- Object
- Input<
T?> - Option<
T?> - SingleOption<
T?> - ChoiceOption
- Implemented types
- Mixed-in types
Constructors
-
ChoiceOption(String name, {required List<
T> choices, String? short, String? description, })
Properties
-
choices
→ List<
T> -
final
- description → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
finalinherited
- isRequired → bool
-
finalinherited
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- short → String?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
required<
T extends Enum> (String name, {required List< T> choices, String? short, String? description, }) → RequiredOption<T> -
withDefault<
T extends Enum> (String name, {required List< T> choices, required T defaultValue, String? short, String? description, }) → DefaultedOption<T>