RepeatableChoiceOption<T extends Enum> class
final
- Inheritance
- Mixed-in types
Constructors
Properties
-
choices
→ List<
T> -
final
- description → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
finalinherited
- isRequired → bool
-
finalinherited
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- short → String?
-
finalinherited
- unique → bool
-
final
Methods
-
appendValue(
Object value, Object? existing) → List< T> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
required<
T extends Enum> (String name, List< T> choices, {String? short, String? description, bool unique = false}) → RequiredRepeatableOption<T> -
withDefault<
T extends Enum> (String name, List< T> choices, {required List<T> defaultValue, String? short, String? description, bool unique = false}) → DefaultedRepeatableOption<T>