RepeatedChoicePositional<T extends Enum> class
final
- Inheritance
-
- Object
- Input<
List< T> > - Positional<
List< T> > - MandatoryPositional<
List< T> > - RepeatedPositional<
T> - RepeatedChoicePositional
- Mixed-in types
Constructors
-
RepeatedChoicePositional(String name, {String? description, required List<
T> choices, int times = 1})
Properties
-
choices
→ List<
T> -
final
- description → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
finalinherited
- regex → RegExp
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- times → int
-
finalinherited
Methods
-
freezeValues(
List< Object> values) → List<T> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited