context library
Classes
- MambaContext
- Mutable state scoped to an executor and shared by all of its executions.
- MambaContextBool
- A bool value stored in MambaContext.
- MambaContextDouble
- A double value stored in MambaContext.
- MambaContextInt
- An int value stored in MambaContext.
-
MambaContextKey<
T extends Object> - A typed identity token for a scalar value stored in MambaContext.
- MambaContextString
- A String value stored in MambaContext.
-
MambaContextValue<
T extends Object> - A closed scalar value that can be stored in MambaContext.
- MambaReadContext
- A read-only view of a MambaContext supplied to ordinary command hooks.