MambaReadContext class
A read-only view of a MambaContext supplied to ordinary command hooks.
Constructors
- MambaReadContext(MambaContext _context)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get<
T extends Object> (MambaContextKey< T> key) → T? -
Returns the unwrapped primitive associated with
key, if one has been set. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited