Executor class final

Constructors

Executor(String name, String shortDescription, String version, List<Command> commands, {String? longDescription, List<AccessorListOption>? accessors, List<Flag>? flags, List<Option>? options, List<String>? defaultCommandPath, MambaContext? context, HelpFormatter? helpFormatter})

Properties

accessors List<AccessorListOption>
final
commands List<Command>
final
context MambaContext?
final
defaultCommandPath List<String>?
final
flags List<Flag>
final
hashCode int
The hash code for this object.
no setterinherited
helpFormatter HelpFormatter?
final
longDescription String?
final
name String
final
options List<Option>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortDescription String
final

Methods

create() MambaExecutor<void>
Creates a process-facing executor.
fake({ProcessedStandardInput? standardInput}) MambaExecutor<MambaExecutionResult>
Creates an executor that returns results without process side effects.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited