integrations library
Classes
- CarapaceSpecConverter
- Converts a typed registry record into a Carapace completion spec.
- CarapaceSpecWriter
- Writes a record-derived Carapace spec to the platform's spec directory.
- RegistryRecordConverter
- Converts a typed registry description into an integration-specific artifact.
- ToBashCompletionConverter
- Compiles a registry record into a portable Bash completion script.
- ToFishCompletionConverter
-
Compiles a registry record into Fish
completedeclarations. - ToPowerShellCompletionConverter
- Compiles a registry record into a native PowerShell argument completer.
- ToZshCompletionConverter
- Compiles a registry record into a native Zsh completion function.