RegistryRecordConverter class abstract
Converts a typed registry description into an integration-specific artifact.
Constructors
- RegistryRecordConverter(RegistryRecord registry)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- registry → RegistryRecord
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
convert(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited