CreateProjectCommand class final
Creates a small Dart package using the current typed command API.
Constructors
- CreateProjectCommand(Directory _parentDirectory)
Properties
-
accessors
→ List<
AccessorListOption> ? -
finalinherited
-
aliases
→ List<
String> ? -
finalinherited
-
conflicts
→ Map<
String, List< ?String> > -
finalinherited
-
discretionaryPositionals
→ List<
DiscretionaryPositional> ? -
finalinherited
-
flags
→ List<
Flag> ? -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- longDescription → String?
-
finalinherited
-
mandatoryPositionals
→ List<
MandatoryPositional> ? -
finalinherited
- name → String
-
no setteroverride
-
options
→ List<
Option> ? -
finalinherited
-
pairedOptions
→ List<
PairedOptionsDefinition> ? -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedOptions
→ List<
SelectedOptions< ?Object> > -
finalinherited
- shortDescription → String
-
no setteroverride
- variadic → Variadic?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
ParsedInputs inputs, List< String> args) → String -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- packageName → NormalPositional
-
final