CommandRegistry class final
Constructors
-
CommandRegistry.create(String name, String shortDescription, {String? longDescription, List<
MandatoryPositional> ? mandatoryPositionals, List<DiscretionaryPositional> ? discretionaryPositionals, Variadic? variadic, List<Flag> ? flags, List<Option> ? options, List<PairedOptionsDefinition> ? pairedOptions, List<SelectedOptions< ? selectedOptions, Map<Object> >String, List< ? conflicts, List<String> >AccessorListOption> ? accessors, List<Command> ? commands}) -
factory
Properties
-
accessors
→ List<
AccessorListOption> -
final
-
applicableAccessors
→ List<
AccessorListOption> -
no setter
-
applicableFlags
→ List<
Flag> -
no setter
-
applicableOptions
→ List<
Option> -
no setter
-
commandAliases
→ List<
String> ? -
final
-
commandRegistries
→ List<
CommandRegistry> -
latefinal
-
commands
→ List<
Command> -
final
-
conflicts
→ Map<
String, List< String> > -
final
-
discretionaryPositionals
→ List<
DiscretionaryPositional> -
final
-
flags
→ List<
Flag> -
final
-
fullPath
→ List<
String> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- helpFlag → BooleanFlag
-
no setter
- longDescription → String?
-
final
-
mandatoryPositionals
→ List<
MandatoryPositional> -
final
- name → String
-
final
-
options
→ List<
Option> -
final
-
pairedOptionGroups
→ List<
PairedOptionsDefinition> -
final
- parent → CommandRegistry?
-
final
-
publishedAccessors
→ List<
AccessorListOption> -
final
-
publishedFlags
→ List<
Flag> -
final
-
publishedOptions
→ List<
Option> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedOptions
→ List<
SelectedOptions< Object> > -
final
- shortDescription → String
-
final
- variadic → Variadic?
-
final
Methods
-
canonicalCommandPath(
List< String> path) → List<String> -
conflictInput(
String name) → InputDefinition? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registeredInputTokenLength(
String token) → int? -
registryForArguments(
List< String> args) → CommandRegistry -
resolveCommandPath(
List< String> args) → CommandResolution - Resolves command tokens while skipping values owned by applicable inputs.
-
toMap(
) → RegistryRecord -
toString(
) → String -
A string representation of this object.
inherited
-
withInheritedInputs(
) → CommandRegistry
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited