CommandResolution class final
Constructors
-
CommandResolution({required CommandRegistry registry, required List<
String> path, required Set<int> tokenIndices}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
path
→ List<
String> -
final
- registry → CommandRegistry
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tokenIndices
→ Set<
int> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited